@@ -1,4 +1,4 @@
-//$Id: examplewindow.h,v 1.2 2006/07/10 03:15:28 jjongsma Exp $ -*- c++ -*-
+//$Id: examplewindow.h,v 1.3 2006/07/19 02:55:20 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,12 +19,7 @@
 #ifndef GTKMM_EXAMPLEWINDOW_H
 #define GTKMM_EXAMPLEWINDOW_H
 
-#include <gtkmm/window.h>
-#include <gtkmm/box.h>
-#include <gtkmm/notebook.h>
-#include <gtkmm/label.h>
-#include <gtkmm/buttonbox.h>
-#include <gtkmm/button.h>
+#include <gtkmm.h>
 
 class ExampleWindow : public Gtk::Window
 {
