@@ -1,4 +1,4 @@
-//$Id: messagetext.h,v 1.2 2006/07/10 03:15:28 jjongsma Exp $ -*- c++ -*-
+//$Id: messagetext.h,v 1.3 2006/07/19 02:55:21 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -19,8 +19,7 @@
 #ifndef GTKMM_EXAMPLE_MESSAGETEXT_H
 #define GTKMM_EXAMPLE_MESSAGETEXT_H
 
-#include <gtkmm/scrolledwindow.h>
-#include <gtkmm/textview.h>
+#include <gtkmm.h>
 
 class MessageText : public Gtk::ScrolledWindow
 {
