@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.2 2006/07/10 03:15:32 jjongsma Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.3 2006/07/19 02:55:24 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -16,10 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include <gtkmm/main.h>
-#include <gtkmm/statusicon.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/window.h>
+#include <gtkmm.h>
 
 int main(int argc, char *argv[])
 {
