@@ -1,4 +1,4 @@
-/* $Id: gtkmm.h 499 2006-01-07 13:19:34Z murrayc $ */
+/* $Id: gtkmm.h,v 1.24 2006/06/20 17:18:16 murrayc Exp $ */
 /* gtkmm - a C++ wrapper for the Gtk toolkit
  *
  * Copyright 1999-2002 The gtkmm Development Team
@@ -37,17 +37,21 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/alignment.h>
 #include <gtkmm/arrow.h>
 #include <gtkmm/aspectframe.h>
+#include <gtkmm/assistant.h>
 #include <gtkmm/base.h>
 #include <gtkmm/bin.h>
 #include <gtkmm/box.h>
 #include <gtkmm/button.h>
 #include <gtkmm/buttonbox.h>
+#include <gtkmm/cellview.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/checkmenuitem.h>
 #include <gtkmm/cellrenderer.h>
+#include <gtkmm/cellrendereraccel.h>
 #include <gtkmm/cellrenderercombo.h>
 #include <gtkmm/cellrendererpixbuf.h>
 #include <gtkmm/cellrendererprogress.h>
+#include <gtkmm/cellrendererspin.h>
 #include <gtkmm/cellrenderertext.h>
 #include <gtkmm/cellrenderertoggle.h>
 #include <gtkmm/colorbutton.h>
@@ -81,6 +85,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/iconset.h>
 #include <gtkmm/iconfactory.h>
 #include <gtkmm/iconsource.h>
+#include <gtkmm/icontheme.h>
 #include <gtkmm/iconview.h>
 #include <gtkmm/image.h>
 #include <gtkmm/imagemenuitem.h>
@@ -89,7 +94,10 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/calendar.h>
 #include <gtkmm/invisible.h>
 #include <gtkmm/label.h>
+#include <gtkmm/layout.h>
 #include <gtkmm/liststore.h>
+#include <gtkmm/listviewtext.h>
+#include <gtkmm/linkbutton.h>
 #include <gtkmm/main.h>
 #include <gtkmm/menu.h>
 #include <gtkmm/menu_elems.h>
@@ -102,12 +110,29 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/object.h>
 #include <gtkmm/optionmenu.h>
 #include <gtkmm/paned.h>
+#include <gtkmm/pagesetup.h>
+#include <gtkmm/pagesetupunixdialog.h>
+#include <gtkmm/papersize.h>
+#include <gtkmm/printcontext.h>
+#include <gtkmm/printer.h>
+#include <gtkmm/printjob.h>
+#include <gtkmm/printoperation.h>
+#include <gtkmm/printoperationpreview.h>
+#include <gtkmm/printsettings.h>
+#include <gtkmm/printunixdialog.h>
 #include <gtkmm/progressbar.h>
 #include <gtkmm/radioaction.h>
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/radiomenuitem.h>
 #include <gtkmm/radiotoolbutton.h>
 #include <gtkmm/range.h>
+#include <gtkmm/recentchooser.h>
+#include <gtkmm/recentchooserdialog.h>
+#include <gtkmm/recentchoosermenu.h>
+#include <gtkmm/recentchooserwidget.h>
+#include <gtkmm/recentfilter.h>
+#include <gtkmm/recentinfo.h>
+#include <gtkmm/recentmanager.h>
 #include <gtkmm/ruler.h>
 #include <gtkmm/scale.h>
 #include <gtkmm/scrollbar.h>
@@ -119,6 +144,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/sizegroup.h>
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/statusbar.h>
+#include <gtkmm/statusicon.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/stockid.h>
 #include <gtkmm/stockitem.h>
